##  Rejecting Discovered Inbox Items
You can reject discovered items to focus on those relevant to your specific enterprise architecture.
To reject discovered items, follow these steps:
  1. From the list, click on the discovery item that needs to be rejected. This opens the side panel.
  2. In the side panel, choose Reject.
